"use strict";

var _react = require("@testing-library/react");
require("@testing-library/jest-dom");
var _runAxeCheck = require("@instructure/ui-axe-check/lib/runAxeCheck.js");
var _index = require("../index");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _ProgressBar, _ProgressBar2, _ProgressBar3;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
describe('<ProgressBar />', () => {
  it('should render', async () => {
    const _render = (0, _react.render)(_ProgressBar || (_ProgressBar = (0, _jsxRuntime.jsx)(_index.ProgressBar, {
        screenReaderLabel: "Chapters read",
        valueMax: 60,
        valueNow: 30
      }))),
      container = _render.container;
    const progress = container.querySelector('progress');
    expect(progress).toBeInTheDocument();
  });
  it('should render a progress element with correct aria attributes', async () => {
    const _render2 = (0, _react.render)(_ProgressBar2 || (_ProgressBar2 = (0, _jsxRuntime.jsx)(_index.ProgressBar, {
        screenReaderLabel: "Chapters read",
        valueMax: 60,
        valueNow: 30
      }))),
      container = _render2.container;
    const progress = container.querySelector('progress');
    expect(progress).toHaveAttribute('value', '30');
  });
  it('should format the displayed text', async () => {
    const current = 30;
    const max = 60;
    const _render3 = (0, _react.render)((0, _jsxRuntime.jsx)(_index.ProgressBar, {
        screenReaderLabel: "Chapters read",
        valueMax: max,
        valueNow: current,
        renderValue: ({
          valueNow,
          valueMax
        }) => `${valueNow} of ${valueMax}`
      })),
      container = _render3.container;
    const progress = container.querySelector('[class*="-progressBar"]');
    expect(progress).toHaveTextContent(`${current} of ${max}`);
  });
  it('should meet a11y standards', async () => {
    const _render4 = (0, _react.render)(_ProgressBar3 || (_ProgressBar3 = (0, _jsxRuntime.jsx)(_index.ProgressBar, {
        screenReaderLabel: "Chapters read",
        valueMax: 60,
        valueNow: 30
      }))),
      container = _render4.container;
    const axeCheck = await (0, _runAxeCheck.runAxeCheck)(container);
    expect(axeCheck).toBe(true);
  });
  it('should not render the value inside when the prop is set to false', () => {
    const valueNow = 33;
    const _render5 = (0, _react.render)((0, _jsxRuntime.jsx)(_index.ProgressBar, {
        screenReaderLabel: "Chapters read",
        valueMax: 100,
        valueNow: valueNow,
        renderValueInside: false,
        renderValue: `${valueNow}%`
      })),
      container = _render5.container;
    const progressMeter = container.querySelector('[class*="-progressBar__trackValue"]');
    expect(progressMeter).not.toHaveTextContent('33%');
  });
  it('should render the value inside when the prop is set', () => {
    const valueNow = 33;
    const _render6 = (0, _react.render)((0, _jsxRuntime.jsx)(_index.ProgressBar, {
        screenReaderLabel: "Chapters read",
        valueMax: 100,
        valueNow: valueNow,
        renderValueInside: true,
        renderValue: `${valueNow}%`
      })),
      container = _render6.container;
    const progressMeter = container.querySelector('[class*="-progressBar__trackValue"]');
    expect(progressMeter).toHaveTextContent('33%');
  });
});