import type { Spacing, WithStyleProps, ComponentStyle } from '@instructure/emotion';
import type { PropValidators, AsElementType, ProgressCircleTheme, OtherHTMLAttributes, Renderable } from '@instructure/shared-types';
export type ProgressCircleMeterColor = 'info' | 'warning' | 'danger' | 'alert' | 'success' | 'brand';
export type Values = {
    valueNow: number;
    valueMax: number;
};
type ProgressCircleOwnProps = {
    /**
     * A label is required for accessibility
     */
    screenReaderLabel: string;
    /**
     * Control the size of the progress circle
     */
    size?: 'x-small' | 'small' | 'medium' | 'large';
    /**
     * Maximum value (defaults to 100)
     */
    valueMax?: Values['valueMax'];
    /**
     * Receives the progress of the event
     */
    valueNow?: Values['valueNow'];
    /**
     * A function for formatting the text provided to screen readers via `aria-valuenow`
     */
    formatScreenReaderValue?: (values: Values) => string;
    /**
     * A function to format the displayed value. If null the value will not display.
     * Takes `valueNow` and `valueMax` as parameters.
     */
    renderValue?: Renderable<Values>;
    /**
     * Controls the overall color scheme of the component
     */
    color?: 'primary' | 'primary-inverse';
    /**
     * Control the color of the progress meter. Defaults to showing theme success
     * color on completion, based on `valueNow` and `valueMax`.
     */
    meterColor?: ((values: Values) => ProgressCircleMeterColor) | ProgressCircleMeterColor;
    /**
     * Valid values are `0`, `none`, `auto`, `xxx-small`, `xx-small`, `x-small`,
     * `small`, `medium`, `large`, `x-large`, `xx-large`. Apply these values via
     * familiar CSS-like shorthand. For example: `margin="small auto large"`.
     */
    margin?: Spacing;
    /**
     * Provides a reference to the component's root HTML element
     */
    elementRef?: (element: Element | null) => void;
    /**
     * Set the element type of the component's root
     */
    as?: AsElementType;
    shouldAnimateOnMount?: boolean;
    animationDelay?: number;
};
export type ProgressCircleState = {
    shouldAnimateOnMount: boolean;
};
type PropKeys = keyof ProgressCircleOwnProps;
type AllowedPropKeys = Readonly<Array<PropKeys>>;
type ProgressCircleProps = ProgressCircleOwnProps & WithStyleProps<ProgressCircleTheme, ProgressCircleStyle> & OtherHTMLAttributes<ProgressCircleOwnProps>;
type ProgressCircleStyle = ComponentStyle<'progressCircle' | 'center' | 'value' | 'circle' | 'track' | 'border' | 'meter' | 'dashOffset'> & {
    radii: {
        radius: string;
        borderOffsetRadius: string;
    };
};
declare const propTypes: PropValidators<PropKeys>;
declare const allowedProps: AllowedPropKeys;
export type { ProgressCircleProps, ProgressCircleStyle };
export { propTypes, allowedProps };
//# sourceMappingURL=props.d.ts.map